from distutils.core import setup
setup(
  name = 'loggable-decorator',
  packages = ['loggable'],
  version = '1.0.0',
  description = 'Add a logger attribute to class decorated',
  author = 'Peter Downs',
  author_email = 'peterldowns@gmail.com',
  url = 'https://github.com/ateliedocodigo/python-loggable-decorator',
  download_url = 'https://github.com/ateliedocodigo/python-loggable-decorator/tarball/1.0.0',
  keywords = ['logging'],
  classifiers = [],
)
